# Google Compute Engine Minimal API (for Testing Purposes Only)

Minimal viable set of API methods from [Google Compute Engine](https://cloud.google.com/error-reporting/reference/). 

These API definitions exist only for testing and to simplify development of 
client libraries for GCE. Please do not depend on or use any of the files from 
this directory in your projects.

